package types

import (
	"time"
)

// MeasuredValue represent a value provided by a measuring instrument. For
// example from a sensor. It can contains different types, for example humidity
// or temperature.
type MeasuredValue struct {
	ID           string            `json:"id" xml:"id"`
	Value        float64           `json:"value,string" xml:"value"`
	ValueType    MeasuredValueType `json:"value_type" xml:"value_type"`
	Date         time.Time         `json:"date" xml:"date"`
	SensorID     string            `json:"sensor_id" xml:"sensor_id"`
	CreationDate time.Time         `json:"creation_date" xml:"creation_date"`
	UpdateDate   *time.Time        `json:"update_date" xml:"update_date"`
}

type MeasuredValueType string

const (
	Humidity    MeasuredValueType = "humidity"
	Pressure    MeasuredValueType = "pressure"
	Temperature MeasuredValueType = "temperature"
)
